#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-IsTC2CW5Yhg74kOL9mIxDG
key:                  ghcide-2.3.0.0-IsTC2CW5Yhg74kOL9mIxDG
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  f28fa568330cea692fb5b656601a19cb
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-IsTC2CW5Yhg74kOL9mIxDG
depends:
    Diff-0.5-YxwELKwzKoB5HD6ND7fY Glob-0.10.2-FE2J3ndE4WZK3er8fA8Irn
    aeson-2.2.1.0-6KokJsif6KIKBUd4sU6s2R array-0.5.6.0
    async-2.2.5-G9iNhoihA4w9hFmxVZ2fQd base-4.18.2.1
    base16-bytestring-1.0.2.0-1V8pBdgUhcODBkL2Ak8rbg binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-1hYZCYjvuIpIceCeIJyCUg
    co-log-core-0.3.2.6-CcbaRQkCR9WKKKCRd1EfmJ containers-0.6.7
    cryptohash-sha1-0.11.101.0-Apa66LQSl7RFPJA6yrBtj5
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-GZOCzoXGFb05faBmnr9K62
    dependent-sum-0.7.2.0-4boKeKdNvyDE25hBTbc0vV directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-rw8IZQEnHU8EsqXP6ogN exceptions-0.10.7
    extra-1.7.16-9wAsXilDxkkB13shWguQct filepath-1.4.300.1
    fingertree-0.1.6.2-KRw5BZGZ42UGlDtQjfNXxj
    focus-1.0.3.2-L6LPCQhNCtpL7sXpqMXrgo ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-89HXRLkaUjyIOCm2SygvBk
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-FTy7W10Qi7M9Ju0dHvfQqC
    hashable-1.4.7.0-T6DCV5EfgDB3vghPWgrCN
    hie-bios-0.12.0-K81EQsXOCMu1PhNSObGOcF
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-BWU9K4yzeGd4GhYisODlrf
    hls-graph-2.3.0.0-8gTPHLWnDoQ9jiFAtc7Qr8
    hls-plugin-api-2.3.0.0-9DNBdoKCSw0LjsyeWtSIfy
    implicit-hie-0.1.4.0-7y3aEjeAJWu8ac2Qh5waIg
    implicit-hie-cradle-0.5.0.1-KmMuN450bpCIYmA3dnMpVa
    lens-5.3.4-2AMucF0ieNI9Rlfgjb79DI
    list-t-1.0.5.7-53iCrcj146C9PVrIrQhp9F
    lsp-2.2.0.0-KrayuyFCa9fBiGdvFwIqs8
    lsp-types-2.0.2.0-JZwPdQdJSIxLrYdPjWduF0 mtl-2.3.1
    opentelemetry-0.8.0-GLF1vwM2lZXAtujOWpK4As
    optparse-applicative-0.18.1.0-8AjHPu2sdPJ6Q2tO4j8kj8
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-EY3nijkmaHU7AF2RkegSvD
    prettyprinter-ansi-terminal-1.1.3-KCm32Jy3Txf2XPgtfozGRB
    random-1.2.1.3-2otWecMyOCFLGjlq6igNwD
    regex-tdfa-1.3.2.5-KomHi09uAwi9maemXWG17h
    row-types-1.0.1.2-BTE4r8c2cZHHcgwvrWpZe6
    safe-exceptions-0.1.7.4-AkFQpeQZgUZ5VDqbpLWXE4
    sorted-list-0.2.3.1-JD5lBKFrnZI6sowJu85gPJ
    sqlite-simple-0.4.19.0-KYS0Kwu9IMTGAZdHlgywJu stm-2.5.1.0
    stm-containers-1.2.1.1-5Tx02EItRXPJVoeWvWaNNK
    syb-0.7.3-8aDoibIh418LOq04kgZkPM text-2.0.2
    text-rope-0.3-JvT1DvI0y8XEZCPQTQkcke time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-5jaLrIl2HQU5QzxG9e9UnM
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-LXAzHO8zZLp8w9V0PnyDcb
    vector-0.13.2.0-91lzNiZgjgOBDn02pUIYXJ

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

